#!/usr/bin/python3
import pyhdb
import datetime
import time
import os
import sys
import getopt
import re
import pprint

# Constants
STATE_OK       = 0
STATE_WARNING  = 1
STATE_CRITICAL = 2
STATE_UNKNOWN  = 3

usage_factor = {
    'percent'  : 1,
    'Byte'     : 1,
    'Kilobyte' : 1024,
    'Megabyte' : 1048576,
    'Gigabyte' : 1073741824,
    'Terabyte' : 1099511627776
}


backupage_factor = {
    'seconds' : 1,
    'minutes' : 60,
    'hours'   : 3600,
    'days'    : 86400
}


def Help():
    print("./check_sap_hana.py --hostname <HOSTNAME> --port <PORT> --username <USER> --password <PASSWORD> --method=<METHOD>")
    print("  --method=<backupage|logbackupage|pendingsession|databackupthroughput|usage|memoryusage|connectiontime|logsegments|currentalerts|listalertid|services|replication|sql>")
    print("  --type <size|log|trace>: additional type when method is usage")
    print("  --alertid: additional ID when method is currentalerts or listalertid. Multiple possible seperated by comma")
    print("  --warning <WARNING>: optional value for warning threshold")
    print("  --critical <WARNING>: optional value for warning threshold")
    print("  --unit <Byte|Kilobyte|Megabyte|Gigabyte|percent>: units for type usage (default: Byte)")
    print("  --unit <seconds|minutes|hours|days>: units for type backupage (default: seconds)")
    print("  --unit optional unit for type")
    print("  --statement <SQL Statement that returns a numeric value>: when method is sql")
    print("  --sqldesc <free text to replace>: must contain text pattern REPLACE, where actual value replaces string REPLACE")
    print("  --help")
    sys.exit(STATE_UNKNOWN)

def calculate_exit(perfvalue, warn, crit):
    # default return OK
    exitcode = STATE_OK
    prefix = 'OK'
    # check if it's a warning state
    if (re.match('^(\d+)$', warn)):
        match = re.match('^(\d+)$', warn)
        if perfvalue > float(match.group(1)) or perfvalue < 0:
            exitcode = STATE_WARNING
    elif (re.match('^(\d+):$', warn)):
        match = re.match('^(\d+):$', warn)
        if (perfvalue < float(match.group(1))):
            exitcode = STATE_WARNING
    elif (re.match('^~:(\d+)$', warn)):
        match = re.match('^~:(\d+)$', warn)
        if (perfvalue > float(match.group(1))):
            exitcode = STATE_WARNING
    elif (re.match('^(\d+):(\d+)$', warn)):
        match = re.match('^(\d+):(\d+)$',warn)
        if (perfvalue < float(match.group(1)) or perfvalue > float(match.group(2))):
            exitcode = STATE_WARNING
    elif (re.match('^@(\d+):(\d+)$', warn)):
        match = re.match('^@(\d+):(\d+)$',warn)
        if (perfvalue >= float(match.group(1)) and perfvalue <= float(match.group(2))):
            exitcode = STATE_WARNING

    # check if it's a critical state
    if (re.match('^(\d+)$', crit)):
        match = re.match('^(\d+)$',crit)
        if (perfvalue > float(match.group(1)) or perfvalue < 0):
            exitcode = STATE_CRITICAL
    elif (re.match('^(\d+):$', crit)):
        match = re.match('^(\d+):$',crit)
        if (perfvalue < float(match.group(1))):
            exitcode = STATE_CRITICAL
    elif (re.match('^~:(\d+)$', crit)):
        match = re.match('^~:(\d+)$',crit)
        if (perfvalue > float(match.group(1))):
            exitcode = STATE_CRITICAL
    elif (re.match('^(\d+):(\d+)$', crit)):
        match = re.match('^(\d+):(\d+)$',crit)
        if (perfvalue < float(match.group(1)) or perfvalue > float(match.group(2))):
            exitcode = STATE_CRITICAL
    elif (re.match('^@(\d+):(\d+)$', crit)):
        match = re.match('^@(\d+):(\d+)$',crit)
        if (perfvalue >= float(match.group(1)) and perfvalue <= float(match.group(2))):
            exitcode = STATE_CRITICAL

    if exitcode == STATE_WARNING:
        prefix = "WARNING"
    if exitcode == STATE_CRITICAL:
        prefix = "CRITICAL"
    if exitcode == STATE_UNKNOWN:
        prefix = "UNKNOWN"
    return exitcode, prefix

def CheckSqlStatement(connection):
    exit_code = STATE_OK
    prefix = 'OK'
    cursor = connection.cursor()
    cursor.execute(Statement)
    value = cursor.fetchone()[0]
    if type(value) is int:
        output = 'value is %s%s' % (value, SQLUnit)
        exit_code, prefix = calculate_exit(value, Warning, Critical)
        if re.search('REPLACE', SQLDesc):
            output = re.sub('REPLACE', '%s' % value, SQLDesc)
        print('%s - %s | value=%s;%s;%s' % (prefix, output, value, Warning, Critical))
    else:
        print('UNKNOWN - Result is not a numeric value')
        exit_code = STATE_UNKNOWN
    sys.exit(exit_code)

def CheckBackupAge(connection):
    # Check HANA Backup Age
    output = ''
    exit_code = STATE_OK
    prefix = 'OK'
    cursor = connection.cursor()
    cursor.execute("SELECT SYS_END_TIME FROM SYS.M_BACKUP_CATALOG WHERE entry_type_name = 'complete data backup' and state_name = 'successful' ORDER BY sys_start_time desc LIMIT 1")
    # seconds since last successful backup
    last_successful_backup = int(time.time() - int(time.mktime(cursor.fetchone()[0].timetuple())))
    seconds_last_successful_backup = last_successful_backup

    last_successful_backup = last_successful_backup / backupage_factor[BackupUnit]
    exit_code, prefix = calculate_exit(last_successful_backup, Warning, Critical)

    print("%s - Backup is %s %s old | seconds=%ss" % (prefix, last_successful_backup, BackupUnit, seconds_last_successful_backup))
    sys.exit(exit_code)

def CheckLogBackupAge(connection):
    # Check HANA Backup Age
    output = ''
    exit_code = STATE_OK
    prefix = 'OK'
    cursor = connection.cursor()
    cursor.execute("SELECT SYS_END_TIME FROM SYS.M_BACKUP_CATALOG WHERE entry_type_name = 'log backup' and state_name = 'successful' ORDER BY sys_start_time desc LIMIT 1")
    # seconds since last successful backup
    last_successful_backup = int(time.time() - int(time.mktime(cursor.fetchone()[0].timetuple())))
    seconds_last_successful_backup = last_successful_backup

    last_successful_backup = last_successful_backup / backupage_factor[BackupUnit]
    exit_code, prefix = calculate_exit(last_successful_backup, Warning, Critical)

    print("%s - Log Backup is %s %s old | seconds=%ss" % (prefix, last_successful_backup, BackupUnit, seconds_last_successful_backup))
    sys.exit(exit_code)

def CheckServices(connection):
    # Check HANA services
    output = ''
    prefix = 'OK'
    exit_code = STATE_OK
    cursor = connection.cursor()
    cursor.execute("SELECT HOST, SERVICE_NAME, ACTIVE_STATUS FROM SYS.M_SERVICES")
    for line in cursor.fetchall():
        if line[2] == 'YES':
            output = output + line[1] + ': ok '
        else:
            output = output + line[1] + ': failed '
            prefix = 'CRITICAL'
            exit_code = STATE_CRITICAL
    print(("%s - Service: %s" % (prefix, output)))
    sys.exit(exit_code)

def CheckLogSegments(connection):
    # Check LOG Segments of Indexserver
    output = ''
    prefix = 'OK'
    exit_code = STATE_OK
    cursor = connection.cursor()
    cursor.execute("SELECT PORT FROM SYS.M_SERVICES WHERE SERVICE_NAME LIKE 'indexserver' and DETAIL like 'master'")
    indexserver_port=cursor.fetchone()[0]
    cursor.execute("SELECT count(*) FROM SYS.M_LOG_SEGMENTS where state in  ( 'Free', 'Preallocated' ) and port = " + str(indexserver_port))
    log_segs=cursor.fetchone()[0]
    exit_code, prefix = calculate_exit(log_segs, Warning, Critical)
    output = '%s - indexserver log segments not free for reuse is %s | log_segs=%s' % (prefix, log_segs, log_segs)
    print(output)
    sys.exit(exit_code)

def CheckCurrentAlerts(connection):
    # Check Specific HANA Alert ID
    output = ''
    prefix = 'OK'
    exit_code = STATE_OK
    alert_name_out = ''
    try:
        AlertID
    except:
        print("UNKNOWN - please provide alertid as integer (--alertid=123)")
        sys.exit(3)

    cursor = connection.cursor()
    cursor.execute("select alert_name, alert_details from _SYS_STATISTICS.STATISTICS_CURRENT_ALERTS where alert_id in (" + str(AlertID) + ") and alert_rating > '3'")
    alerts=cursor.fetchall()


    if len(alerts) == 0:
        exit_code = STATE_OK
        prefix = 'OK'
        cursor.execute("SELECT ALERT_NAME FROM _SYS_STATISTICS.STATISTICS_ALERT_INFORMATION WHERE ALERT_ID in (" + str(AlertID) + ")")
        alert_names=cursor.fetchall()
        for alert_name in alert_names:
            alert_name_out = alert_name_out + "###" + alert_name[0] + "###" + ', '
        output= '%s - %s no current alerts present with rating > 3' % (prefix, alert_name_out[:-2])

    else:
        exit_code = STATE_CRITICAL
        prefix = 'CRITICAL'
        for alert_name, alert_details in alerts:
            alert_name_out = alert_name_out + "###" + alert_name + "###: " + alert_details + ', '
        output= '%s - %s' % (prefix, alert_name_out[:-2])

    print(output)
    sys.exit(exit_code)


def ListAlertIDs(connection):
    # List all Alert IDs and NAMES
    exit_code = STATE_OK
    cursor = connection.cursor()
    try:
        AlertID
        cursor.execute("SELECT ALERT_ID, ALERT_NAME FROM _SYS_STATISTICS.STATISTICS_ALERT_INFORMATION WHERE ALERT_ID in (" + str(AlertID) + ") ORDER BY ALERT_ID")
    except:
        cursor.execute("SELECT ALERT_ID, ALERT_NAME FROM _SYS_STATISTICS.STATISTICS_ALERT_INFORMATION ORDER BY ALERT_ID")


    alert=cursor.fetchall()
    for alert_id, alert_name in alert:
        print(alert_id, "\t", alert_name)


    sys.exit(exit_code)

def CheckReplication(connection):
    # Checks HANA Replication Status
    exit_code = STATE_OK
    prefix = 'OK'
    replication_out = ''
    cursor = connection.cursor()
    cursor.execute("select site_name, replication_status from M_SYSTEM_REPLICATION")

    replication=cursor.fetchall()

    if len(replication) == 0:
        output = "%s - no replication related information found" % (prefix)

    else:
        for site_name, replication_status in replication:
            if replication_status.lower() != 'active':
                exit_code = STATE_CRITICAL
                prefix = 'CRITICAL'
            replication_out=replication_out + site_name + ': ' + replication_status + ', '
        output = '%s - %s' % (prefix, replication_out[:-2])

    print(output)
    sys.exit(exit_code)

def CheckPendingSessions(connection):
    # Checks HANA Replication Status
    exit_code = STATE_OK
    prefix = 'OK'
    pendingsessions_out = ''
    pendingsessions_out_perf = ''
    cursor = connection.cursor()
    cursor.execute("select s.service_name as service, max(pending_session_count) as v_max from m_load_history_service l inner join m_services s on l.host = s.host and l.port = s.port where time > add_seconds(current_timestamp, -900) group by s.service_name")

    pendingsessions=cursor.fetchall()

    if len(pendingsessions) == 0:
        output = "%s - no session related information found" % (prefix)

    else:
        for service_name, v_max in pendingsessions:
            if v_max >= 0:
                exit_code_tmp, prefix_tmp = calculate_exit(v_max, Warning, Critical)
            if exit_code_tmp > exit_code:
                exit_code = exit_code_tmp,
                prefix = prefix_tmp
            pendingsessions_out = pendingsessions_out + service_name + ': ' + str(v_max) + ', '
            pendingsessions_out_perf = pendingsessions_out_perf + "pend_" + service_name + '=' + str(v_max) + ' '
        output = '%s - pending sessions %s | %s' % (prefix, pendingsessions_out[:-2], pendingsessions_out_perf)

    print(output)
    sys.exit(exit_code)

def CheckBackupThroughput(connection):
    # Checks HANA Data Backup Throughput
    exit_code = STATE_OK
    prefix = 'OK'
    replication_out = ''
    cursor = connection.cursor()
    cursor.execute("SELECT TO_CHAR(TO_DECIMAL(AVG(MAP(BACKUP_DURATION_H, 0, 0, BACKUP_SIZE_GB / BACKUP_DURATION_H)), 10, 2)) as v_avg FROM ( SELECT B.ENTRY_TYPE_NAME, SECONDS_BETWEEN(B.SYS_START_TIME, B.SYS_END_TIME) / 3600 BACKUP_DURATION_H, ( SELECT SUM(BACKUP_SIZE) / 1024 / 1024 / 1024 FROM M_BACKUP_CATALOG_FILES BF WHERE BF.BACKUP_ID = B.BACKUP_ID ) BACKUP_SIZE_GB FROM M_BACKUP_CATALOG B WHERE B.STATE_NAME = 'successful' AND DAYS_BETWEEN(B.SYS_START_TIME, CURRENT_TIMESTAMP) <= 1 )  where (  ENTRY_TYPE_NAME LIKE '%data%' )  group by ENTRY_TYPE_NAME")

    try:
        throughput=cursor.fetchone()[0]
        output='%s - Avg. data backup throughput (GB/h, yesterday) is %s | bck=%s' % (prefix, throughput, throughput)
    except:
        prefix = 'UNKNOWN'
        exit_code = STATE_UNKNOWN
        output='%s - could not find backup related performance values' % (prefix)


    print(output)
    sys.exit(exit_code)

def CheckMemoryUsage(connection):
    cursor = connection.cursor()
    cursor.execute("select (m1.INSTANCE_TOTAL_MEMORY_USED_SIZE/m1.ALLOCATION_LIMIT*100) as PERCENTAGE_USED from SYS.M_HOST_RESOURCE_UTILIZATION m1  join sys.m_landscape_host_configuration as s on m1.host = s.host where UPPER(s.host_actual_roles) not like '%STANDBY%'")
    percent_used=cursor.fetchone()[0]
    exit_code, prefix = calculate_exit(percent_used, Warning, Critical)
    output = '%s - %s percent used | usage=%s;%s;%s' % (prefix, percent_used, percent_used, Warning, Critical)

    print(output)
    sys.exit(exit_code)

def CheckConnectionTime(connection):
    cstart=time.time()
    cursor = connection.cursor()
    cursor.execute("select VERSION FROM SYS.M_DATABASE")
    hversion=cursor.fetchone()[0]
    cend=time.time()
    ctime=(cend - cstart)
    exit_code, prefix = calculate_exit(ctime, Warning, Critical)
    output = '%s - connectiontime %ss version: %s | connectiontime=%ss;%s;%s' % (prefix, ctime, hversion, ctime, Warning, Critical)

    print(output)
    sys.exit(exit_code)

def CheckEWAIndexMem(connection):
    cursor = connection.cursor()
    cursor.execute("SELECT TOTAL_MEMORY_USED_SIZE FROM M_SERVICE_MEMORY where Service_name='indexserver'")

    val=cursor.fetchone()[0]

    print("OK - indexserver memory consumption: %s | mem=%s" %(val, val))
    exit(STATE_OK)

def CheckEWAIndexHeap(connection):
    cursor = connection.cursor()
    cursor.execute("SELECT HEAP_MEMORY_USED_SIZE FROM M_SERVICE_MEMORY where Service_name='indexserver'")

    val=cursor.fetchone()[0]

    print("OK - indexserver heap consumption: %s | heap=%s" %(val, val))
    exit(STATE_OK)

def CheckEWAMemoryRow(connection):
    cursor = connection.cursor()
    cursor.execute("SELECT SUM(ALLOCATED_SIZE) ROW_STORE_USED_SIZE FROM M_RS_MEMORY")

    val=cursor.fetchone()[0]

    print("OK - memory allocation row: %s | memory=%s" %(val, val))
    exit(STATE_OK)

def CheckEWAMemoryColumn(connection):
    cursor = connection.cursor()
    cursor.execute("SELECT sum(MEMORY_SIZE_IN_TOTAL) FROM M_CS_TABLES")

    val=cursor.fetchone()[0]

    print("OK - memory allocation column: %s | memory=%s" %(val, val))
    exit(STATE_OK)

def CheckEWAColumnUnloads(connection):
    cursor = connection.cursor()
    cursor.execute("select count(*) from m_cs_unloads where reason != 'MERGE' and schema_name LIKE 'SAP%' and substr(unload_time, 0, 10) LIKE CURRENT_DATE")

    val=cursor.fetchone()[0]

    print("OK - column unloads is %s | unloads=%s" % (val, val))
    exit(STATE_OK)

def CheckEWASchemaSize(connection):
    output=''
    output_perf=''
    longoutput=''
    cursor = connection.cursor()

    cursor.execute("SELECT SCHEMA_NAME AS SCHEMA, round(sum(MEMORY_SIZE_IN_TOTAL) /1024/1024) AS MB FROM M_CS_TABLES GROUP BY SCHEMA_NAME ORDER BY MB DESC")

    for line in cursor.fetchall():
        output=output + ("(%s: %s), " % (line[0], line[1]))
        output_perf=output_perf + ("%s=%s " % (line[0], line[1]))
        longoutput=longoutput + ("%s: %s\n" % (line[0], line[1]))

    print("OK - schema sizes: %s | %s" % (output[:-2], output_perf))
    print(longoutput)
    exit(STATE_OK)

def CheckEWAT10LargeRowStoreTables(connection):
    output=''
    output_perf=''
    longoutput=''
    cursor = connection.cursor()

    cursor.execute("select top 10 SCHEMA_NAME, TABLE_NAME, TABLE_SIZE from sys.M_tables where TABLE_TYPE='ROW' order by TABLE_SIZE desc")

    for line in cursor.fetchall():
        output=output + ("(%s: %s), " % (line[1], line[2]))
        output_perf=output_perf + ("%s=%s " % (line[1], line[2]))
        longoutput=longoutput + ("%s___%s___%s\n" % (line[0], line[1], line[2]))

    print("OK - large row store tables: %s | %s" % (output[:-2], output_perf))
    print(longoutput)
    exit(STATE_OK)

def CheckEWAT10LargeColumnStoreTables(connection):
    output=''
    output_perf=''
    longoutput=''
    cursor = connection.cursor()

    cursor.execute("select top 10 SCHEMA_NAME, TABLE_NAME, TABLE_SIZE from sys.M_tables where TABLE_TYPE='COLUMN' order by TABLE_SIZE desc")

    for line in cursor.fetchall():
        output=output + ("(%s: %s), " % (line[1], line[2]))
        output_perf=output_perf + ("%s=%s " % (line[1], line[2]))
        longoutput=longoutput + ("%s___%s___%s\n" % (line[0], line[1], line[2]))

    print("OK - large column store tables: %s | %s" % (output[:-2], output_perf))
    print(longoutput)
    exit(STATE_OK)

def CheckUsage(connection):
    cursor = connection.cursor()
    cursor.execute("SELECT * FROM SYS.M_SYSTEM_OVERVIEW")
    output = ''
    prefix = 'OK'
    exit_code = STATE_OK
    for line in cursor.fetchall():
        if line[0] == 'Disk' and line[1] == 'Data' and Type == 'size':
            size = float(re.sub(r'Size (.*) GB, Used .* GB, Free .* %', r'\1', line[3])) * 1024 * 1024 * 1024
            size_used = float(re.sub(r'Size .* GB, Used (.*) GB, Free .* %', r'\1', line[3])) * 1024 * 1024 * 1024
            percent_used = round((size_used / size) * 100, 0)
            size_used_byte = int(size_used)
            size_used = int(size_used) / usage_factor[UsageUnit]
            size = int(size) / usage_factor[UsageUnit]
        if line[0] == 'Disk' and line[1] == 'Log' and Type == 'log':
            size = float(re.sub(r'Size (.*) GB, Used .* GB, Free .* %', r'\1', line[3])) * 1024 * 1024 * 1024
            size_used = float(re.sub(r'Size .* GB, Used (.*) GB, Free .* %', r'\1', line[3])) * 1024 * 1024 * 1024
            percent_used = round((size_used / size) * 100, 0)
            size_used_byte = int(size_used)
            size_used = int(size_used) / usage_factor[UsageUnit]
            size = int(size) / usage_factor[UsageUnit]
        if line[0] == 'Disk' and line[1] == 'Trace' and Type == 'trace':
            size = float(re.sub(r'Size (.*) GB, Used .* GB, Free .* %', r'\1', line[3])) * 1024 * 1024 * 1024
            size_used = float(re.sub(r'Size .* GB, Used (.*) GB, Free .* %', r'\1', line[3])) * 1024 * 1024 * 1024
            percent_used = round((size_used / size) * 100, 0)
            size_used_byte = int(size_used)
            size_used = int(size_used) / usage_factor[UsageUnit]
            size = int(size) / usage_factor[UsageUnit]
        if line[0] == 'Memory' and line[1] == 'Memory' and Type == 'memory':
            size = float(re.sub(r'Physical (.*) GB, Swap .* GB, Used .*', r'\1', line[3])) * 1024 * 1024 * 1024
            size_used = float(re.sub(r'Physical .* GB, Swap .* GB, Used (.*)', r'\1', line[3])) * 1024 * 1024 * 1024
            percent_used = round((size_used / size) * 100, 0)
            size_used_byte = int(size_used)
            size_used = int(size_used) / usage_factor[UsageUnit]
            size = int(size) / usage_factor[UsageUnit]
    if UsageUnit == 'percent':
        exit_code, prefix = calculate_exit(percent_used, Warning, Critical)
        output = '%s - %s percent used | usage=%s' % (prefix, percent_used, size_used_byte)
    else:
        exit_code, prefix = calculate_exit(size_used, Warning, Critical)
        output = '%s - Usage: %s %s Total size: %s %s (%s percent used)| usage=%s' % (prefix, size_used, UsageUnit, size, UsageUnit, percent_used, size_used_byte)
    print(output)
    sys.exit(exit_code)
def CheckHanaDatabase():
    hana_error = 0
    try:
        connection = pyhdb.connect(
            host=Host,
            port=Port,
            user=User,
            password=Password
        )
        if Method == 'backupage':
            CheckBackupAge(connection)
        elif Method == 'logbackupage':
            CheckLogBackupAge(connection)
        elif Method == 'services':
            CheckServices(connection)
        elif Method == 'usage':
            CheckUsage(connection)
        elif Method == 'logsegments':
            CheckLogSegments(connection)
        elif Method == 'replication':
            CheckReplication(connection)
        elif Method == 'memoryusage':
            CheckMemoryUsage(connection)
        elif Method == 'connectiontime':
            CheckConnectionTime(connection)
        elif Method == 'currentalerts':
            CheckCurrentAlerts(connection)
        elif Method == 'ewa_schemasize':
            CheckEWASchemaSize(connection)
        elif Method == 'ewa_t10largerowstoretables':
            CheckEWAT10LargeRowStoreTables(connection)
        elif Method == 'ewa_t10largecolumnstoretables':
            CheckEWAT10LargeColumnStoreTables(connection)
        elif Method == 'ewa_columnunloads':
            CheckEWAColumnUnloads(connection)
        elif Method == 'ewa_indexmem':
            CheckEWAIndexMem(connection)
        elif Method == 'ewa_indexheap':
            CheckEWAIndexHeap(connection)
        elif Method == 'ewa_memory_row':
            CheckEWAMemoryRow(connection)
        elif Method == 'ewa_memory_column':
            CheckEWAMemoryColumn(connection)
        elif Method == 'databackupthroughput':
            CheckBackupThroughput(connection)
        elif Method == 'pendingsession':
            CheckPendingSessions(connection)
        elif Method == 'listalertids':
            ListAlertIDs(connection)
        elif Method == 'sql':
            CheckSqlStatement(connection)
        else:
            print("UNKNOWN - mode %s is not available" %(Method))
        connection.close()
    except Exception as e:
        print("CRITICAL - " + str(e))
        hana_error = 2
        exit_code = STATE_CRITICAL
        sys.exit(exit_code)
    return hana_error

# Get commandline options
try:
    CommandLineOptions, Arguments = getopt.getopt(sys.argv[1:], 'H:vU:S:t:a:w:c:u:hm:p:', ['hostname=', 'help', 'username=', 'password=', 'port=', 'verbose', 'method=', 'warning=', 'critical=', 'unit=', 'type=', 'statement=', 'alertid=', 'sqldesc='])
except:
    print("UNKNOWN - Error fetching arguments")
    sys.exit(3)

Host = None
User = None
Password = None
SysNr = None
Method = None
Warning = ""
Critical = ""
Unit = None
BackupUnit = 'seconds'
UsageUnit = 'Byte'
SQLUnit = ''
SQLDesc = ''

for Option,Argument in CommandLineOptions:
    if Option in [ '-H', '--hostname' ]:
        Host = Argument
    if Option in [ '-U', '--username' ]:
        User = Argument
    if Option in [ '-S', '--password' ]:
        Password = Argument
    if Option in [ '-p', '--port' ]:
       Port = Argument
    if Option in [ '-t', '--type' ]:
        Type = Argument
    if Option in [ '-a', '--alertid' ]:
        AlertID = Argument
    if Option in [ '-m', '--method' ]:
        Method = Argument
    if Option in [ '-u', '--unit' ]:
        Unit = Argument
    if Option in [ '-w', '--warning' ]:
        Warning = Argument
    if Option in [ '-c', '--critical' ]:
        Critical = Argument
    if Option in [ '-h', '--help' ]:
        Help()
    if Option in [ '--statement' ]:
        Statement = Argument
    if Option in [ '--sqldesc' ]:
        SQLDesc = Argument

if Host is None or User is None or Password is None or Port is None or Method is None:
    Help()

if Method == 'usage' and Unit is not None:
    UsageUnit = Unit
if (Method == 'backupage' or Method == 'logbackupage') and Unit is not None:
    BackupUnit = Unit
if Method == 'sql' and Unit is not None:
    SQLUnit = Unit

CheckHanaDatabase()
